function dP = Psi_P(func,P,varargin) 
% PURPOSE: compute the gradient of Psi(P) with respect to P
% ------------------------------------------------
% USAGE: dP        = Psi_P(func,param,varargin)
% Where: func       = Psi()
%        P      = (ns x nglob) parameter vector at which to evaluate
%        varargin   = other arguments passed to the function
% ------------------------------------------------
% RETURNS:
%		 dP  = (ns*nglob x ns*nglob) matrix with the gradient
% ------------------------------------------------
%
% Written by Hiroyuki Kasahara, University of British Columbia 
% Last Updated: July 2009 


[ns,nglob] = size(P);
param = P(:);

k = length(param);

eps = 1e-8; % this corresponds to the accuracy of solving fp

% Compute the stepsize (h)
h = eps^(2/3).*max(abs(param),1);   % no need to add sign(param) because 
%h = sqrt(eps).*max(abs(param),1);   % no need to add sign(param) because 
                                    % we take a two-sided difference
th = param + h;
h = th - param;   % avoid round-off error
ee = sparse(1:k,1:k,h,k,k);
 
% Compute forward step 
p_0 = feval(func,P,varargin{:});
dP = zeros(k);


for i=1:k
    
    q_1 = reshape(param+ee(:,i),ns,nglob);  
    q_0 = reshape(param-ee(:,i),ns,nglob);   
    %grd0 = (feval(func,q_1,varargin{:})-p_0)./h(i);
    grd0 = (feval(func,q_1,varargin{:})-feval(func,q_0,varargin{:}))./(2*h(i));
    grd0 = grd0(:);
    
    if any(isnan(grd0))
        dP = NaN*ones(length(grd0),k);
        break
    end
    
    dP(:,i) = grd0;
     
end
