function dP = Psi_theta(func,np,P,param,varargin) 
% PURPOSE: compute the gradient of Psi(P) with respect to theta
% ------------------------------------------------
% USAGE: dP        = Psi_theta(func,P,param,varargin)
% Where: func       = Psi()
%        P      = (ns x nglob) parameter vector at which to evaluate
%        param = (npar x 1)
%        varargin   = other arguments passed to the function
% ------------------------------------------------
% RETURNS:
%		 dP  = (ns*nglob x npar) matrix with the gradient
% ------------------------------------------------
%
% Written by Hiroyuki Kasahara, University of British Columbia 
% Last Updated: July 2009 

 

[ns,nglob] = size(P); 
k = length(param);

eps = 1e-8; % this corresponds to the accuracy of solving fp

% Compute the stepsize (h)
h = eps^(2/3).*max(abs(param),1);   % no need to add sign(param) because 
%h = sqrt(eps).*max(abs(param),1);   % no need to add sign(param) because 
                                    % we take a two-sided difference
th = param + h;
h = th - param;   % avoid round-off error
ee = sparse(1:k,1:k,h,k,k);
  

% Compute forward step  
dP = zeros(ns*nglob,np);


for i=1:np
     
    grd0 = (feval(func,P,param+ee(:,i),varargin{:})-feval(func,P,param-ee(:,i),varargin{:}))./(2*h(i));
    grd0 = grd0(:);
    
    if any(isnan(grd0))
        dP = NaN*ones(length(grd0),k);
        break
    end
    
    dP(:,i) = grd0;
     
end
