function [loglike, dloglike] = clogit(b,s_0,a_0,a_1,AA)
% compute an initial estimator with logit approximation.  
%
%   INPUT
% b: a vector of parameter 
%
%   OUTPUT
%   loglike = \sum_(m=1}^M\sum_{i=1}^N log L_{im}(a|x)
%   dloglike = derivative of loglike
% 
% Written by Hiroyuki Kasahara, UBC
% Last Updated: July 2009

[nobs,nglob] = size(a_1); 
b = reshape(b,2+nglob,nglob);

P_i = zeros(nobs,nglob);
for i = 1:nglob 
    P_i(:,i) = max(min(1./(1+exp(-b(1,i)-b(2,i)*s_0-AA(a_0,:)*b(3:2+nglob,i))),1-1e-16),1e-16);  
end
% lnP_0 = log(1-exp(lnP_1));
 
loglike = 0;
for i = 1:nglob 
    loglike = loglike - sum( a_1(:,i).*log(P_i(:,i)) + (1-a_1(:,i)).*log(1-P_i(:,i)) );
end
 
dloglike = zeros(2+nglob,nglob);
for j = 1:2+nglob
    for i = 1:nglob
        P = P_i(:,i);
        if j == 1
            dlnP_1 = (1-P);
            dlnP_0 = -P;
        elseif j == 2
            dlnP_1 = (1-P).*s_0;
            dlnP_0 = -P.*s_0;
        elseif j>=3
            dlnP_1 = (1-P).*AA(a_0,j-2);
            dlnP_0 = -P.*AA(a_0,j-2);
        end 
        dloglike(j,i) = dloglike(j,i) - sum( a_1(:,i).*dlnP_1 + (1-a_1(:,i)).*dlnP_0 );
    end
end
dloglike = dloglike(:);

return

