function [DP,iflag] = f_phi_population_NAG(n,P_0,iflag)
% computes phi_0(P_0)-P_0
%
% INPUT
% P_0: the initial value of P
% theta: the true parameter value
% p_star: population distribution of x
% P_1_star: population discrete choice probability
%
% OUTPUT: the vector value of phi_0(P_0)-P_0 
%
% Call the following function-m file: logit_Psi_population.m
% 
% Written by Hiroyuki Kasahara, UBC
% Last Updated: June 2011
 
global theta f_s SS AA b_j p_star P_1_star  
 
[ns,nglob]=size(P_1_star); 
P_0 = reshape(P_0,ns,nglob); 
%   Step 1: compute(z_tilde,lambda_tilde) given P_j  
[z_tilde,lambda_tilde] = z_lambda(P_0,f_s,SS,AA);  
%   Step 2: compute the parameter estimate given P_0 --- for robustness,
%   try four different initial values of theta
options = optimset('Display','off','GradObj','on','LargeScale','off','TolFun',1e-8,'TolX',1e-8,'MaxFunEvals',1000,'MaxIter',1000);
[b1,fval1]  = fminunc('logit_Psi_population',b_j(:,1),options,theta,z_tilde,lambda_tilde,p_star,P_1_star);
[b2,fval2]  = fminunc('logit_Psi_population',b_j(:,2),options,theta,z_tilde,lambda_tilde,p_star,P_1_star); 
[b3,fval3]  = fminunc('logit_Psi_population',b_j(:,3),options,theta,z_tilde,lambda_tilde,p_star,P_1_star);
[b4,fval4]  = fminunc('logit_Psi_population',b_j(:,4),options,theta,z_tilde,lambda_tilde,p_star,P_1_star); 
fval = [fval1;fval2;fval3;fval4];
bb = [b1,b2,b3,b4];
[f,j] = min(fval);
b = bb(:,j);
%   Step 3: update P_j
theta_b = theta;
theta_b(1:2,1) = b;
P_1 = Psi(P_0,theta_b,f_s,SS,AA); % a standard mapping
%P_1 = Lambda(P_0,theta_b,f_s,SS,AA,0.8); % a weighted average mapping
        
DP = P_0-P_1;

return

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% function [loglike, dloglike] = logit_Psi_population(b,theta,z_tilde,lambda_tilde,p_star,P_1_star)
% % computes the expected pseudo loglikelihood based on Psi mapping at population
% %
% %   INPUT
% % b: a vector of parameter
% % z_tilde: (ns x npar_i x nglob)
% % lambda_tilde: (ns x nglob)
% % p_star: population distribution of x
% % P_1_star: population discrete choice probability
% %
% %   OUTPUT
% %   loglike = E[\sum_{i=1}^N log L_{im}(a|x)]
% %   dloglike = (d/d\theta)E[\sum_{i=1}^N log L_{im}(a|x)]
% %
% % 
% % Written by Hiroyuki Kasahara, UBC
% % Last Updated: July 2009
% 
% [ns,nglob] = size(lambda_tilde);
% npar_i = size(z_tilde,2);
% npar = length(theta);
% 
% theta_i = zeros(npar_i,nglob);
% theta_i(1:2,:) = repmat(b,1,nglob);
% theta_i(3,:) = repmat(theta(3),1,nglob);
% theta_i(4,:) =  theta(4:3+nglob); 
% 
% P_i = zeros(ns,nglob);
% for i = 1:nglob
%     P_i(:,i) = max(min(1./(1+exp(-squeeze(z_tilde(:,:,i))*theta_i(:,i)-lambda_tilde(:,i))),1-1e-16),1e-16); 
% end 
% 
% loglike = 0;
% for i = 1:nglob
%     P = P_i(:,i);
%     loglike = loglike - sum( p_star.*(P_1_star(:,i).*log(P) + (1-P_1_star(:,i)).*log(1-P)) );
%     % expectation is taken with respect to (a,x)
% end
% 
% dloglike = zeros(2,1);
% for j = 1:2
%     for i = 1:nglob
%         P = P_i(:,i);
%         %dP = P.*(1-P).*squeeze(zz(:,j,i));
%         dlnP_1 = (1-P).*squeeze(z_tilde(:,j,i));
%         dlnP_0 = -P.*squeeze(z_tilde(:,j,i));
%         dloglike(j) = dloglike(j) - sum( P_1_star(:,i).*dlnP_1 + (1-P_1_star(:,i)).*dlnP_0 );
%     end
% end
% 
%return

