function loglike = logit_Lambda(b,theta,zz,lambda,a_1,P,alpha)
% computes the pseudo loglikelihood based on the mapping based on weighted
% average (i.e., Lambda=\Psi^{\alpha}P^{1-\alpha})
%
%   INPUT
% b: a vector of parameter
% z_tilde: (ns x npar_i x nglob)
% lambda_tilde: (ns x nglob)
% a_1: observation for entry/exit choices
% P: an initial estimator for P 
% alpha: determines the weight between Psi and P
%
%   OUTPUT
%   loglike = \sum_(m=1}^M\sum_{i=1}^N log Lambda_{im}(a|x) 
%
%
% Written by Hiroyuki Kasahara, UBC
% Last Updated: July 2009

[nobs,nglob] = size(lambda);
npar_i = size(zz,2);
npar = length(theta);

theta_i = zeros(npar_i,nglob);
theta_i(1:2,:) = repmat(b,1,nglob);
theta_i(3,:) = repmat(theta(3),1,nglob);
theta_i(4,:) =  theta(4:3+nglob); 

P_i = zeros(nobs,nglob);
for i = 1:nglob
    P_i(:,i) = max(min(1./(1+exp(-squeeze(zz(:,:,i))*theta_i(:,i)-lambda(:,i))),1-1e-16),1e-16); 
end 

P = max(min(P,1-1e-16),1e-16);  
P_i = (P_i.^alpha).*(P.^(1-alpha));

loglike = 0;
for i = 1:nglob
    P = P_i(:,i);
    loglike = loglike - sum( a_1(:,i).*log(P) + (1-a_1(:,i)).*log(1-P) );
end
 
return

