function [loglike ] = logit_P_theta(b,theta,dat,z_tilde,lambda_tilde,a_1,dP_dtheta,P_1,b_0)
% computes the approximate loglikelihood based of AFXP algorithm
%
%   INPUT
% b: parameter to be estimated
% theta: contains other parameters
% dat: the observations
% z_tilde: (ns x npar_i x nglob)
% lambda_tilde: (ns x nglob)
% a_1: (ns x nglob)
% dP_dtheta: (dP)/(dtheta)
% P_1: an estimated conditional choice probabilities
% b_0: an initial estimator  
%
%   OUTPUT
%   loglike = \sum_(m=1}^M\sum_{i=1}^N log \Phi_{im}(a|x) 
%
% Written by Hiroyuki Kasahara, UBC
% Last Updated: July 2009
 
[nobs,nglob] = size(a_1);
[ns,nglob] = size(lambda_tilde);
npar_i = size(z_tilde,2);
npar = length(theta); 

theta_i = zeros(npar_i,nglob);
theta_i(1:2,:) = repmat(b,1,nglob);
theta_i(3,:) = repmat(theta(3),1,nglob);
theta_i(4,:) =  theta(4:3+nglob); 
  
P_1 = dP_dtheta*(b-b_0) + P_1(:); 
epsilon = 1e-8;
P_max = max(P_1,1-epsilon)-(1-epsilon);
P_min = min(P_1,epsilon); 
%penalty = reshape(exp(min(100*(P_max-P_min),50)),ns,nglob);
penalty = reshape(exp(min((1/epsilon^0.5)*(P_max-P_min),50)),ns,nglob);
 
P_1 = max(min(P_1,1-epsilon),epsilon);  
P_1 = reshape(P_1,ns,nglob);
lnP_1 = log(P_1);
lnP_0 = log(1-P_1);  

loglike = 0;
penal = 0;
for i = 1:nglob 
     loglike = loglike - sum( a_1(:,i).*lnP_1(dat(:,1,i),i) + (1-a_1(:,i)).*lnP_0(dat(:,1,i),i) );
     penal = penal + sum(penalty(dat(:,1,i),i))-nobs;
end  
loglike = loglike + 100*penal;



% dloglike = zeros(npar,1);
% for j = 1:3 
%     dPsi = P_s.*(1-P_s).*squeeze(z_tilde(:,j,:));
%     dlnP_1 = inv_I_P*dPsi(:)./P_1(:);
%     dlnP_1 = reshape(dlnP_1,ns,nglob); 
%     dlnP_0 = -dlnP_1.*P_1./(1-P_1); 
%     for i = 1:nglob 
%         dloglike(j) = dloglike(j) - sum( a_1(:,i).*dlnP_1(dat(:,1,i),i) + (1-a_1(:,i)).*dlnP_0(dat(:,1,i),i) );
%     end
% end  
% dPsi = P_s.*(1-P_s).*squeeze(z_tilde(:,4,:));
% dlnP_1 = inv_I_P*dPsi(:)./P_1(:);
% dlnP_1 = reshape(dlnP_1,ns,nglob); 
% dlnP_0 = -dlnP_1.*P_1./(1-P_1);  
% for i = 1:nglob 
%     dloglike(3+i) = - sum( a_1(:,i).*dlnP_1(dat(:,1,i),i) + (1-a_1(:,i)).*dlnP_0(dat(:,1,i),i) );
% end




return

