function [loglike, dloglike] = logit_Psi(b,theta,zz,lambda,a_1)
% computes the pseudo loglikelihood based on Psi mapping
%
%   INPUT
% b: a vector of parameter
% z_tilde: (ns x npar_i x nglob)
% lambda_tilde: (ns x nglob)
% a_1: observation for entry/exit choices 
%
%   OUTPUT
%   loglike = \sum_(m=1}^M\sum_{i=1}^N log L_{im}(a|x)
%   dloglike = (d/d\theta)\sum_(m=1}^M\sum_{i=1}^N log L_{im}(a|x)
%
% 
% Written by Hiroyuki Kasahara, UBC
% Last Updated: July 2009

[nobs,nglob] = size(lambda);
npar_i = size(zz,2);
npar = length(theta);

theta_i = zeros(npar_i,nglob);
theta_i(1:2,:) = repmat(b,1,nglob);
theta_i(3,:) = repmat(theta(3),1,nglob);
theta_i(4,:) =  theta(4:3+nglob); 

P_i = zeros(nobs,nglob);
for i = 1:nglob
    P_i(:,i) = max(min(1./(1+exp(-squeeze(zz(:,:,i))*theta_i(:,i)-lambda(:,i))),1-1e-16),1e-16); 
end 

loglike = 0;
for i = 1:nglob
    P = P_i(:,i);
    loglike = loglike - sum( a_1(:,i).*log(P) + (1-a_1(:,i)).*log(1-P) );
end

dloglike = zeros(2,1);
for j = 1:2
    for i = 1:nglob
        P = P_i(:,i);
        %dP = P.*(1-P).*squeeze(zz(:,j,i));
        dlnP_1 = (1-P).*squeeze(zz(:,j,i));
        dlnP_0 = -P.*squeeze(zz(:,j,i));
        dloglike(j) = dloglike(j) - sum( a_1(:,i).*dlnP_1 + (1-a_1(:,i)).*dlnP_0 );
    end
end

% dloglike = zeros(npar,1);
% for j = 1:3
%     for i = 1:nglob
%         P = P_i(:,i);
%         %dP = P.*(1-P).*squeeze(zz(:,j,i));
%         dlnP_1 = (1-P).*squeeze(zz(:,j,i));
%         dlnP_0 = -P.*squeeze(zz(:,j,i));
%         dloglike(j) = dloglike(j) - sum( a_1(:,i).*dlnP_1 + (1-a_1(:,i)).*dlnP_0 );
%     end
% end
% for i = 1:nglob
%     P = P_i(:,i);
%     %dP = P.*P.*squeeze(zz(:,4,i)).*exp(-squeeze(zz(:,:,i))*theta_i(:,i)-lambda(:,i));
%     dlnP_1 = (1-P).*squeeze(zz(:,4,i));
%     dlnP_0 = -P.*squeeze(zz(:,4,i));
%     dloglike(3+i) = dloglike(3+i) - sum( a_1(:,i).*dlnP_1 + (1-a_1(:,i)).*dlnP_0 );
% end

return

