function [loglike, dloglike] = logit_Psi_population(b,theta,z_tilde,lambda_tilde,p_star,P_1_star)
% computes the expected pseudo loglikelihood based on Psi mapping at population
%
%   INPUT
% b: a vector of parameter
% z_tilde: (ns x npar_i x nglob)
% lambda_tilde: (ns x nglob)
% p_star: population distribution of x
% P_1_star: population discrete choice probability
%
%   OUTPUT
%   loglike = E[\sum_{i=1}^N log L_{im}(a|x)]
%   dloglike = (d/d\theta)E[\sum_{i=1}^N log L_{im}(a|x)]
%
% 
% Written by Hiroyuki Kasahara, UBC
% Last Updated: July 2009

[ns,nglob] = size(lambda_tilde);
npar_i = size(z_tilde,2);
%npar = length(theta);

theta_i = zeros(npar_i,nglob);
theta_i(1:2,:) = repmat(b,1,nglob);
theta_i(3,:) = repmat(theta(3),1,nglob);
theta_i(4,:) =  theta(4:3+nglob); 

P_i = zeros(ns,nglob);
for i = 1:nglob
    P_i(:,i) = max(min(1./(1+exp(-squeeze(z_tilde(:,:,i))*theta_i(:,i)-lambda_tilde(:,i))),1-1e-16),1e-16); 
end 

loglike = 0;
for i = 1:nglob
    P = P_i(:,i);
    loglike = loglike - sum( p_star.*(P_1_star(:,i).*log(P) + (1-P_1_star(:,i)).*log(1-P)) );
    % expectation is taken with respect to (a,x)
end

dloglike = zeros(2,1);
for j = 1:2
    for i = 1:nglob
        P = P_i(:,i);
        %dP = P.*(1-P).*squeeze(zz(:,j,i));
        dlnP_1 = (1-P).*squeeze(z_tilde(:,j,i));
        dlnP_0 = -P.*squeeze(z_tilde(:,j,i));
        dloglike(j) = dloglike(j) - sum( P_1_star(:,i).*dlnP_1 + (1-P_1_star(:,i)).*dlnP_0 );
    end
end

% dloglike = zeros(npar,1);
% for j = 1:3
%     for i = 1:nglob
%         P = P_i(:,i);
%         %dP = P.*(1-P).*squeeze(zz(:,j,i));
%         dlnP_1 = (1-P).*squeeze(zz(:,j,i));
%         dlnP_0 = -P.*squeeze(zz(:,j,i));
%         dloglike(j) = dloglike(j) - sum( a_1(:,i).*dlnP_1 + (1-a_1(:,i)).*dlnP_0 );
%     end
% end
% for i = 1:nglob
%     P = P_i(:,i);
%     %dP = P.*P.*squeeze(zz(:,4,i)).*exp(-squeeze(zz(:,:,i))*theta_i(:,i)-lambda(:,i));
%     dlnP_1 = (1-P).*squeeze(zz(:,4,i));
%     dlnP_0 = -P.*squeeze(zz(:,4,i));
%     dloglike(3+i) = dloglike(3+i) - sum( a_1(:,i).*dlnP_1 + (1-a_1(:,i)).*dlnP_0 );
% end

return

