function  loglike = logit_RPM(b,theta,dat,z_tilde,lambda_tilde,a_1,P_1,Z,inv_I_f,Proj_Q)
% computes the approximate loglikelihood using RPM algorithm
%
%   INPUT
% b: a vector of parameter
% z_tilde: (ns x npar_i x nglob)
% lambda_tilde: (ns x nglob)
% a_1: (ns x nglob)
% P_1: an initial estimator for conditional choice probabilities
% Z: orthonomal basis generated by basis_RPM.m
% inv_I_f: = (I-Z'*Psi_P_Z)^{-1}
% Proj_Q = I-\Pi = I - ZZ' 
%
%   OUTPUT
%   loglike = \sum_(m=1}^M\sum_{i=1}^N log \Gamma_{im}(a|x) 
%
% Written by Hiroyuki Kasahara, UBC
% Last Updated: July 2009

[nobs,nglob] = size(a_1);
[ns,nglob] = size(lambda_tilde);
npar_i = size(z_tilde,2);
npar = length(theta); 

theta_i = zeros(npar_i,nglob);
theta_i(1:2,:) = repmat(b,1,nglob);
theta_i(3,:) = repmat(theta(3),1,nglob);
theta_i(4,:) =  theta(4:3+nglob);  
 
% Psi(P,theta)
P_i = zeros(ns,nglob);
for i = 1:nglob
    P_i(:,i) = max(min(1./(1+exp(-squeeze(z_tilde(:,:,i))*theta_i(:,i)-lambda_tilde(:,i))),1-1e-16),1e-16); 
end 
P_i = P_i(:);
 
Lambda = P_1(:) + (Z*inv_I_f*Z'+Proj_Q)*(P_i(:)-P_1(:));   

% Computing penalty term
epsilon = 1e-8;
P_max = max(Lambda,1-epsilon)-(1-epsilon);
P_min = min(Lambda,epsilon); 
penalty = reshape(exp(min((1/epsilon^0.5)*(P_max-P_min),50)),ns,nglob);
 
% truncated loglikelihood
Lambda = max(min(Lambda,1-epsilon),epsilon);  
Lambda = reshape(Lambda,ns,nglob);
lnP_1 = log(Lambda);
lnP_0 = log(1-Lambda);
  
loglike = 0;
penal = 0;
for i = 1:nglob 
     loglike = loglike - sum( a_1(:,i).*lnP_1(dat(:,1,i),i) + (1-a_1(:,i)).*lnP_0(dat(:,1,i),i) );
     penal = penal + sum(penalty(dat(:,1,i),i))-nobs;
end  
loglike = loglike + penal;



% dloglike = zeros(npar,1);
% for j = 1:3 
%     dPsi = P_s.*(1-P_s).*squeeze(z_tilde(:,j,:));
%     dlnP_1 = inv_I_P*dPsi(:)./P_1(:);
%     dlnP_1 = reshape(dlnP_1,ns,nglob); 
%     dlnP_0 = -dlnP_1.*P_1./(1-P_1); 
%     for i = 1:nglob 
%         dloglike(j) = dloglike(j) - sum( a_1(:,i).*dlnP_1(dat(:,1,i),i) + (1-a_1(:,i)).*dlnP_0(dat(:,1,i),i) );
%     end
% end  
% dPsi = P_s.*(1-P_s).*squeeze(z_tilde(:,4,:));
% dlnP_1 = inv_I_P*dPsi(:)./P_1(:);
% dlnP_1 = reshape(dlnP_1,ns,nglob); 
% dlnP_0 = -dlnP_1.*P_1./(1-P_1);  
% for i = 1:nglob 
%     dloglike(3+i) = - sum( a_1(:,i).*dlnP_1(dat(:,1,i),i) + (1-a_1(:,i)).*dlnP_0(dat(:,1,i),i) );
% end




return

